@@ -1,8 +1,3 @@
-# SPDX-FileCopyrightText: 2023-present patel <khush@base.ai>
-#
-# SPDX-License-Identifier: MIT
-
-from lyzr.generator import Generator
 from lyzr.chatqa.chatbot import ChatBot
 from lyzr.base.llm import LyzrLLMFactory
 from lyzr.chatqa.qa_bot import QABot
@@ -10,6 +5,8 @@ from lyzr.base.service import LyzrService
 from lyzr.base.vector_store import LyzrVectorStoreIndex
 from lyzr.formula_generator import FormulaGen
 from lyzr.data_analyzr import DataAnalyzr
+from lyzr.data_analyzr import DataConnector
+from lyzr.voicebot import VoiceBot
 
 __all__ = [
     "LyzrLLMFactory",
@@ -18,6 +15,6 @@ __all__ = [
     "QABot",
     "ChatBot",
     "FormulaGen",
-    "Generator",
-    "DataAnalyzr"
+    "DataAnalyzr",
+    "DataConnector" "VoiceBot",
 ]
